summaryrefslogtreecommitdiffstats
path: root/Source/WebKit/android/jni/WebSettings.cpp
diff options
context:
space:
mode:
authorKristian Monsen <kristianm@google.com>2011-06-27 10:47:13 +0100
committerKristian Monsen <kristianm@google.com>2011-06-29 15:12:47 +0100
commita5b05f64bda3dea3ba23e77e9eb2ef59812cdc86 (patch)
treebcca417ac5437d5c3376556e0513fafe3539be4b /Source/WebKit/android/jni/WebSettings.cpp
parentc19571f3ec3bec025fa05e8d81ffd1998324e844 (diff)
downloadexternal_webkit-a5b05f64bda3dea3ba23e77e9eb2ef59812cdc86.zip
external_webkit-a5b05f64bda3dea3ba23e77e9eb2ef59812cdc86.tar.gz
external_webkit-a5b05f64bda3dea3ba23e77e9eb2ef59812cdc86.tar.bz2
Merge Chromium at r11.0.696.0: Just AutoFill => Autofill renaming
Change-Id: Iefb91f0b784c26b503125017ae3582a28e7d530d
Diffstat (limited to 'Source/WebKit/android/jni/WebSettings.cpp')
-rw-r--r--Source/WebKit/android/jni/WebSettings.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/Source/WebKit/android/jni/WebSettings.cpp b/Source/WebKit/android/jni/WebSettings.cpp
index 6f18695..589615d 100644
--- a/Source/WebKit/android/jni/WebSettings.cpp
+++ b/Source/WebKit/android/jni/WebSettings.cpp
@@ -293,7 +293,7 @@ inline string16 getStringFieldAsString16(JNIEnv* env, jobject autoFillProfile, j
return str ? jstringToString16(env, str) : string16();
}
-void syncAutoFillProfile(JNIEnv* env, jobject autoFillProfile, WebAutoFill* webAutoFill)
+void syncAutoFillProfile(JNIEnv* env, jobject autoFillProfile, WebAutofill* webAutofill)
{
string16 fullName = getStringFieldAsString16(env, autoFillProfile, gFieldIds->mAutoFillProfileFullName);
string16 emailAddress = getStringFieldAsString16(env, autoFillProfile, gFieldIds->mAutoFillProfileEmailAddress);
@@ -306,7 +306,7 @@ void syncAutoFillProfile(JNIEnv* env, jobject autoFillProfile, WebAutoFill* webA
string16 country = getStringFieldAsString16(env, autoFillProfile, gFieldIds->mAutoFillProfileCountry);
string16 phoneNumber = getStringFieldAsString16(env, autoFillProfile, gFieldIds->mAutoFillProfilePhoneNumber);
- webAutoFill->setProfile(fullName, emailAddress, companyName, addressLine1, addressLine2, city, state, zipCode, country, phoneNumber);
+ webAutofill->setProfile(fullName, emailAddress, companyName, addressLine1, addressLine2, city, state, zipCode, country, phoneNumber);
}
#endif
@@ -554,16 +554,16 @@ public:
if (flag) {
EditorClientAndroid* editorC = static_cast<EditorClientAndroid*>(pFrame->page()->editorClient());
- WebAutoFill* webAutoFill = editorC->getAutoFill();
- // Set the active AutoFillProfile data.
+ WebAutofill* webAutofill = editorC->getAutofill();
+ // Set the active AutofillProfile data.
jobject autoFillProfile = env->GetObjectField(obj, gFieldIds->mAutoFillProfile);
if (autoFillProfile)
- syncAutoFillProfile(env, autoFillProfile, webAutoFill);
+ syncAutoFillProfile(env, autoFillProfile, webAutofill);
else {
// The autofill profile is null. We need to tell Chromium about this because
// this may be because the user just deleted their profile but left the
// autofill feature setting enabled.
- webAutoFill->clearProfiles();
+ webAutofill->clearProfiles();
}
}
#endif